stm32-metapac

Crates

git

Versions

stm32h562zg

Flavors

Bdcr

Struct Bdcr 

#[repr(transparent)]
pub struct Bdcr(pub u32);
PWR Backup domain control register.

Tuple Fields

0: u32

Implementations



impl Bdcr

pub const fn bren(&self) -> Retention

Backup RAM retention in Standby and V_BAT modes When this bit set, the backup regulator (used to maintain the backup RAM content in Standby and V_BAT modes) is enabled. If BREN is cleared, the backup regulator is switched off. The backup RAM can still be used in. Run and Stop modes. However its content is lost in Standby and V_BAT modes. If BREN is set, the application must wait till the backup regulator ready flag (BRRDY) is set to indicate that the data written into the SRAM is maintained in Standby and V_BAT modes.

pub const fn set_bren(&mut self, val: Retention)

Backup RAM retention in Standby and V_BAT modes When this bit set, the backup regulator (used to maintain the backup RAM content in Standby and V_BAT modes) is enabled. If BREN is cleared, the backup regulator is switched off. The backup RAM can still be used in. Run and Stop modes. However its content is lost in Standby and V_BAT modes. If BREN is set, the application must wait till the backup regulator ready flag (BRRDY) is set to indicate that the data written into the SRAM is maintained in Standby and V_BAT modes.

pub const fn monen(&self) -> bool

Backup domain voltage and temperature monitoring enable.

pub const fn set_monen(&mut self, val: bool)

Backup domain voltage and temperature monitoring enable.

pub const fn vbe(&self) -> bool

V_BAT charging enable Note: Reset only by POR,.

pub const fn set_vbe(&mut self, val: bool)

V_BAT charging enable Note: Reset only by POR,.

pub const fn vbrs(&self) -> Vbrs

V_BAT charging resistor selection.

pub const fn set_vbrs(&mut self, val: Vbrs)

V_BAT charging resistor selection.